@@ -27,11 +27,11 @@ __all__ = [
 
 # Where your project will look for your data (for instance, images and ui
 # files). By default, this is ../data, relative your trunk layout
-__catfish_data_directory__ = '/usr/share/catfish/'
+__catfish_data_directory__ = '/build/catfish/pkg/catfish/usr/share/catfish'
 # Location of locate.db file
 __locate_db_path__ = '/var/lib/mlocate/mlocate.db'
 __license__ = 'GPL-2+'
-__version__ = '4.16.0'
+__version__ = '4.16.1'
 __url__ = 'https://docs.xfce.org/apps/catfish/start'
 
 
